@@ -1,11 +1,11 @@
-# Maintained now in B::C by Reini Urban <rurban@x-ray.at>
+# Maintained now in B::C by Reini Urban <rurban@cpan.org>
 package B::Bblock;
 
 our $VERSION = '1.04';
 
 use Exporter ();
 @ISA       = "Exporter";
-@EXPORT_OK = qw(find_leaders);
+our @EXPORT_OK = qw(find_leaders);
 
 use B qw(peekop walkoptree walkoptree_exec
   main_root main_start svref_2object
