@@ -3,7 +3,7 @@ package qr_loaded_module;
 my $var = 1;
 my $qr_with_var = qr/^_?[^\W_0-9]\w*$var/;
 sub qr_called_in_sub {
-	$name =~ $qr_with_var;
+	$_[0] =~ $qr_with_var;
 }
 1;
 
