@@ -565,8 +565,10 @@ tests[144]='print index("long message\0xx","\0")'
 result[144]='12'
 tests[145]='my $bits = 0; for (my $i = ~0; $i; $i >>= 1) { ++$bits; }; print $bits'
 result[145]=`$PERL -MConfig -e'print 8*$Config{ivsize}'`
-tests[146]='my $a = v120.300; my $b = v200.400; $a ^= $b; print sprintf("%vd", $a);'
-result[146]='176.188'
+if [[ $v524 -eq 0 ]]; then # Use of strings with code points over 0xFF as arguments to bitwise xor (^) operator is deprecated in perl 5.24
+  tests[146]='my $a = v120.300; my $b = v200.400; $a ^= $b; print sprintf("%vd", $a);'
+  result[146]='176.188'
+fi
 tests[148]='open(FH, ">", "ccode148i.tmp"); print FH "1\n"; close FH; print -s "ccode148i.tmp"'
 result[148]='2'
 tests[149]='format Comment =
@@ -1418,6 +1420,24 @@ tests[367]='#BROKEN since 5.22 (METHOP for binc)
 use Math::BigInt;
 my $x = Math::BigInt->new('1' x 20);
 print "ok" if ++$x eq "11111111111111111112";'
+tests[390]='print test(); print test();
+sub test() {
+    *test = sub ()  { "k" };
+    "o";
+}'
+tests[391]='use warnings "closed"; eval "warn qq(\n); print qq(ok\n)";'
+tests[400]='#TODO
+use Class::XSAccessor constructor => "new", accessors => [ "foo" ];
+my $o = main::->new( foo => "ok" );
+print $o->foo,"\n";'
+tests[4001]='require Class::XSAccessor;
+Class::XSAccessor->import(constructor => "new", accessors => [ "foo" ]);
+my $o = main::->new( foo => "ok" );
+print $o->foo,"\n";'
+tests[4002]='use Class::XSAccessor;
+Class::XSAccessor->import(constructor => "new", accessors => [ "foo" ]);
+my $o = main::->new( foo => "ok" );
+print $o->foo,"\n";'
 
 init
 
